package com.ruoyi.web.controller.zdsz;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.zdsz.domain.bo.WasteMaterialBo;
import com.ruoyi.zdsz.domain.vo.WasteMaterialVo;
import com.ruoyi.zdsz.domain.vo.ZEngineeringWasteMaterialVo;
import com.ruoyi.zdsz.service.IZEngineeringWasteMaterialService;
import lombok.RequiredArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 四大工程 耗材统计
 *
 * @author ruoyi
 * @date 2024-01-02
 */
@Validated
@RequiredArgsConstructor
@RestController
@RequestMapping("/zdsz/engineeringWasteMaterial")
public class ZEngineeringWasteMaterialController extends BaseController {

    private final IZEngineeringWasteMaterialService izEngineeringWasteMaterialService;

    /**
     * 四大工程 统计展示
     */
    @GetMapping("/{id}/{type}")
    public R<ZEngineeringWasteMaterialVo> querys(@NotNull(message = "主键不能为空") @PathVariable String id, @NotNull(message = "类型不能为空") @PathVariable String type) {
        switch (type){
            case "engineeringIndustry":{ // 工业工程
                return R.ok(izEngineeringWasteMaterialService.queryEngineeringIndustry(id));
            }
            case "engineeringMunicipal":{ // 市政工程
                return R.ok(izEngineeringWasteMaterialService.queryEngineeringMunicipal(id));
            }
            case "engineeringPipeJacking":{ // 顶管工程
                return R.ok(izEngineeringWasteMaterialService.queryEngineeringPipeJacking(id));
            }
            case "touchOperationEngineering":{ // 碰口作业
                return R.ok(izEngineeringWasteMaterialService.queryTouchOperationEngineering(id));
            }
            default:{
                return R.fail("类型或主键无效");
            }
        }
    }

    /**
     * 四大工程 统计展示 PC用料统计
     */
    @GetMapping("/engineeringIndustryList")
    public R<List> engineeringIndustryList(WasteMaterialBo bo) { // 工业工程
        return R.ok(izEngineeringWasteMaterialService.engineeringIndustryList(bo));
    }
    @GetMapping("/engineeringMunicipalList")
    public R<List> engineeringMunicipalList(WasteMaterialBo bo) { // 市政工程
        return R.ok(izEngineeringWasteMaterialService.engineeringMunicipalList(bo));
    }
    @GetMapping("/engineeringPipeJackingList")
    public R<List> engineeringPipeJackingList(WasteMaterialBo bo) { // 顶管工程
        return R.ok(izEngineeringWasteMaterialService.engineeringPipeJackingList(bo));
    }
    @GetMapping("/engineeringInfrastructureList")
    public R<List> engineeringInfrastructureList(WasteMaterialBo bo) { // 基建工程
        return R.ok(izEngineeringWasteMaterialService.engineeringInfrastructureList(bo));
    }
    /**
     * 导出 PC用料统计
     */
    @Log(title = "工业工程用料统计", businessType = BusinessType.EXPORT)
    @PostMapping("/engineeringIndustryExport")
    public void engineeringIndustryList(WasteMaterialBo bo, HttpServletResponse response) { // 工业工程
        ExcelUtil.exportExcel(izEngineeringWasteMaterialService.engineeringIndustryList(bo), "用料统计", WasteMaterialVo.class, response);
    }
    @Log(title = "市政工程用料统计", businessType = BusinessType.EXPORT)
    @PostMapping("/engineeringMunicipalExport")
    public void engineeringMunicipalList(WasteMaterialBo bo, HttpServletResponse response) { // 市政工程
        ExcelUtil.exportExcel(izEngineeringWasteMaterialService.engineeringIndustryList(bo), "市政工程用料统计", WasteMaterialVo.class, response);
    }
    @Log(title = "顶管工程用料统计", businessType = BusinessType.EXPORT)
    @PostMapping("/engineeringPipeJackingExport")
    public void engineeringPipeJackingList(WasteMaterialBo bo, HttpServletResponse response) { // 顶管工程
        ExcelUtil.exportExcel(izEngineeringWasteMaterialService.engineeringIndustryList(bo), "顶管工程用料统计", WasteMaterialVo.class, response);
    }
    @Log(title = "基建工程用料统计", businessType = BusinessType.EXPORT)
    @PostMapping("/engineeringInfrastructureExport")
    public void engineeringInfrastructureList(WasteMaterialBo bo, HttpServletResponse response) { // 基建工程
        ExcelUtil.exportExcel(izEngineeringWasteMaterialService.engineeringIndustryList(bo), "基建工程用料统计", WasteMaterialVo.class, response);
    }
}
